@@ -1,9 +1,9 @@
-# Copyright 2001-2006 The Apache Software Foundation or its licensors, as
-# applicable.
-#
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
+# Licensed to the Apache Software Foundation (ASF) under one or more
+# contributor license agreements.  See the NOTICE file distributed with
+# this work for additional information regarding copyright ownership.
+# The ASF licenses this file to You under the Apache License, Version 2.0
+# (the "License"); you may not use this file except in compliance with
+# the License.  You may obtain a copy of the License at
 #
 #     http://www.apache.org/licenses/LICENSE-2.0
 #
@@ -73,6 +73,22 @@ sub configure_modperl {
         Apache::TestRun::exit_perl(0);
     }
 
+    if ($rev == 2) {
+        # load apreq2 if it is present
+        # do things a bit differently that find_and_load_module()
+        # because apreq2 can't be loaded that way (the 2 causes a problem)
+        my $name = 'mod_apreq2.so';
+        my $mod_path = $test_config->find_apache_module($name) or return;
+
+        # don't match the 2 here
+        my ($sym) = $name =~ m/mod_(\w+)2\./;
+
+        if ($mod_path && -e $mod_path) {
+            $test_config->preamble(IfModule => "!mod_$sym.c",
+                        qq{LoadModule ${sym}_module "$mod_path"\n});
+        }
+    }
+
     $test_config->preamble_register(qw(configure_libmodperl
                                        configure_env));
 
